@@ -51,7 +51,7 @@ class MutateMixin:
         with ImportExtensions(required=True):
             from sgqlc.endpoint.http import HTTPEndpoint as SgqlcHTTPEndpoint
 
-            proto = 'https' if self.args.https else 'http'
+            proto = 'https' if self.args.tls else 'http'
             graphql_url = f'{proto}://{self.args.host}:{self.args.port}/graphql'
             endpoint = SgqlcHTTPEndpoint(graphql_url)
             res = endpoint(
@@ -98,6 +98,7 @@ class PostMixin:
         request_size: int = 100,
         show_progress: bool = False,
         continue_on_error: bool = False,
+        return_responses: bool = False,
         **kwargs,
     ) -> Optional[Union['DocumentArray', List['Response']]]:
         """Post a general data request to the Flow.
@@ -111,7 +112,9 @@ class PostMixin:
         :param target_executor: a regex string. Only matching Executors will process the request.
         :param request_size: the number of Documents per request. <=0 means all inputs in one request.
         :param show_progress: if set, client will show a progress bar on receiving every request.
-        :param continue_on_error: if set, a Request that causes callback error will be logged only without blocking the further requests.
+        :param continue_on_error: if set, a Request that causes callback error will be logged only without blocking the further requests.7
+        :param return_responses: if set to True, the result will come as Response and not as a `DocumentArray`
+
         :param kwargs: additional parameters
         :return: None or DocumentArray containing all response Documents
 
@@ -119,33 +122,37 @@ class PostMixin:
             ``target_executor`` uses ``re.match`` for checking if the pattern is matched. ``target_executor=='foo'`` will match both deployments with the name ``foo`` and ``foo_what_ever_suffix``.
         """
 
-        return_results = False
+        c = self.client
 
-        async def _get_results(*args, **kwargs):
-            result = []
-            c = self.client
-            c.show_progress = show_progress
-            c.continue_on_error = continue_on_error
-            async for resp in c._get_results(*args, **kwargs):
-                if return_results:
-                    result.append(resp)
+        if c.args.return_responses and not return_responses:
+            warnings.warn(
+                'return_responses was set in the Client constructor. Therefore, we are overriding the `.post()` input '
+                'parameter `return_responses`. This argument will be deprecated from the `constructor` '
+                'soon. We recommend passing `return_responses` to the `post` method.'
+            )
+            return_responses = True
 
-            if return_results:
-                if not c.args.return_responses:
-                    docs = [r.data.docs for r in result]
-                    if len(docs) < 1:
-                        return docs
-                    else:
-                        return docs[0].reduce_all(docs[1:])
-                else:
-                    return result
-
-        if (on_always is None) and (on_done is None):
-            return_results = True
+        c.show_progress = show_progress
+        c.continue_on_error = continue_on_error
 
         parameters = _include_results_field_in_param(parameters)
         on_error = _wrap_on_error(on_error) if on_error is not None else on_error
 
+        from jina import DocumentArray
+
+        return_results = (on_always is None) and (on_done is None)
+
+        async def _get_results(*args, **kwargs):
+            result = [] if return_responses else DocumentArray()
+            async for resp in c._get_results(*args, **kwargs):
+                if return_results:
+                    if return_responses:
+                        result.append(resp)
+                    else:
+                        result.extend(resp.data.docs)
+            if return_results:
+                return result
+
         return run_async(
             _get_results,
             inputs=inputs,
@@ -181,6 +188,7 @@ class AsyncPostMixin:
         request_size: int = 100,
         show_progress: bool = False,
         continue_on_error: bool = False,
+        return_responses: bool = False,
         **kwargs,
     ) -> AsyncGenerator[None, Union['DocumentArray', 'Response']]:
         """Async Post a general data request to the Flow.
@@ -195,6 +203,7 @@ class AsyncPostMixin:
         :param request_size: the number of Documents per request. <=0 means all inputs in one request.
         :param show_progress: if set, client will show a progress bar on receiving every request.
         :param continue_on_error: if set, a Request that causes callback error will be logged only without blocking the further requests.
+        :param return_responses: if set to True, the result will come as Response and not as a `DocumentArray`
         :param kwargs: additional parameters
         :yield: Response object
 
@@ -202,6 +211,15 @@ class AsyncPostMixin:
             ``target_executor`` uses ``re.match`` for checking if the pattern is matched. ``target_executor=='foo'`` will match both deployments with the name ``foo`` and ``foo_what_ever_suffix``.
         """
         c = self.client
+
+        if c.args.return_responses and not return_responses:
+            warnings.warn(
+                'return_responses was set in the Client constructor. Therefore, we are overriding the `.post()` input '
+                'parameter `return_responses`. This argument will be deprecated from the `constructor` '
+                'soon. We recommend passing `return_responses` to the `post` method.'
+            )
+            return_responses = True
+
         c.show_progress = show_progress
         c.continue_on_error = continue_on_error
 
@@ -219,7 +237,7 @@ class AsyncPostMixin:
             request_size=request_size,
             **kwargs,
         ):
-            if not c.args.return_responses:
+            if not return_responses:
                 yield result.data.docs
             else:
                 yield result
@@ -232,7 +250,6 @@ class AsyncPostMixin:
 
 
 def _wrap_on_error(on_error):
-
     num_args = len(signature(on_error).parameters)
     if num_args == 1:
         warnings.warn(
