@@ -4,16 +4,16 @@ import json
 import os
 import shutil
 from pathlib import Path
-from typing import Tuple, Optional
+from typing import Tuple
 
-from . import HubExecutor
-from .helper import unpack_package, install_requirements
-from ..helper import random_identity
-
-_hub_root = Path(
-    os.environ.get('JINA_HUB_ROOT', Path.home().joinpath('.jina', 'hub-packages'))
+from jina.helper import random_identity
+from jina.hubble import HubExecutor
+from jina.hubble.helper import (
+    get_hub_packages_dir,
+    install_requirements,
+    is_requirements_installed,
+    unpack_package,
 )
-_hub_root.mkdir(parents=True, exist_ok=True)
 
 
 def get_dist_path(uuid: str, tag: str) -> Tuple[Path, Path]:
@@ -22,7 +22,7 @@ def get_dist_path(uuid: str, tag: str) -> Tuple[Path, Path]:
     :param tag: the TAG of the executor
     :return: package and its dist-info path
     """
-    pkg_path = _hub_root / uuid
+    pkg_path = get_hub_packages_dir() / uuid
     pkg_dist_path = pkg_path / f'{tag}.dist-info'
     return pkg_path, pkg_dist_path
 
@@ -49,14 +49,14 @@ def get_config_path(local_id: str) -> 'Path':
     :param local_id: the random local ID of the executor
     :return: json config path
     """
-    return _hub_root / f'{local_id}.json'
+    return get_hub_packages_dir() / f'{local_id}.json'
 
 
 def get_lockfile() -> str:
     """Get the path of file locker
     :return: the path of file locker
     """
-    return str(_hub_root / 'LOCK')
+    return str(get_hub_packages_dir() / 'LOCK')
 
 
 def load_secret(work_path: 'Path') -> Tuple[str, str]:
@@ -128,7 +128,7 @@ def dump_secret(work_path: 'Path', uuid8: str, secret: str):
 def install_local(
     zip_package: 'Path',
     executor: 'HubExecutor',
-    install_deps: Optional[bool] = False,
+    install_deps: bool = False,
 ):
     """Install the package in zip format to the Jina Hub root.
 
@@ -149,21 +149,42 @@ def install_local(
     # create dist-info folder
     pkg_dist_path.mkdir(parents=False, exist_ok=True)
 
-    # install the dependencies included in requirements.txt
-    if install_deps:
-        requirements_file = pkg_path / 'requirements.txt'
-        if requirements_file.exists():
-            install_requirements(requirements_file)
-            shutil.copyfile(requirements_file, pkg_dist_path / 'requirements.txt')
+    install_package_dependencies(install_deps, pkg_dist_path, pkg_path)
 
     manifest_path = pkg_path / 'manifest.yml'
     if manifest_path.exists():
         shutil.copyfile(manifest_path, pkg_dist_path / 'manifest.yml')
 
-    # store the serial number in local
-    if executor.sn is not None:
-        sn_file = pkg_dist_path / f'PKG-SN-{executor.sn}'
-        sn_file.touch()
+    # store the commit id in local
+    if executor.commit_id is not None:
+        commit_file = pkg_dist_path / f'PKG-COMMIT-{executor.commit_id}'
+        commit_file.touch()
+
+
+def install_package_dependencies(
+    install_deps: bool, pkg_dist_path: 'Path', pkg_path: 'Path'
+) -> None:
+    """
+
+    :param install_deps: if set, then install dependencies
+    :param pkg_dist_path: package distribution path
+    :param pkg_path: package path
+    """
+    # install the dependencies included in requirements.txt
+    requirements_file = pkg_path / 'requirements.txt'
+
+    if requirements_file.exists():
+        if pkg_path != pkg_dist_path:
+            shutil.copyfile(requirements_file, pkg_dist_path / 'requirements.txt')
+
+        if install_deps:
+            install_requirements(requirements_file)
+        elif not is_requirements_installed(requirements_file, show_warning=True):
+            raise ModuleNotFoundError(
+                'Dependencies listed in requirements.txt are not all installed locally, '
+                'this Executor may not run as expect. To install dependencies, '
+                'add `--install-requirements` or set `install_requirements = True`'
+            )
 
 
 def uninstall_local(uuid: str):
@@ -172,7 +193,7 @@ def uninstall_local(uuid: str):
     :param uuid: the UUID of the executor
     """
     pkg_path, _ = get_dist_path(uuid, None)
-    for dist in _hub_root.glob(f'{uuid}/*.dist-info'):
+    for dist in get_hub_packages_dir().glob(f'{uuid}/*.dist-info'):
         shutil.rmtree(dist)
     if pkg_path.exists():
         shutil.rmtree(pkg_path)
@@ -184,7 +205,7 @@ def list_local():
     :return: the list of local executors (if found)
     """
     result = []
-    for dist_name in _hub_root.glob(r'*/v*.dist-info'):
+    for dist_name in get_hub_packages_dir().glob(r'*/v*.dist-info'):
         result.append(dist_name)
 
     return result
