@@ -1,3 +1,4 @@
+import copy
 import logging
 import logging.handlers
 import os
@@ -5,10 +6,11 @@ import platform
 import sys
 from typing import Optional
 
-from . import formatter
-from .. import __uptime__, __resources_path__, __windows__
-from ..enums import LogVerbosity
-from ..jaml import JAML
+from rich.logging import RichHandler
+
+from jina.enums import LogVerbosity
+from jina.jaml import JAML
+from jina.logging import formatter
 
 
 class SysLogHandlerWrapper(logging.handlers.SysLogHandler):
@@ -36,24 +38,21 @@ class JinaLogger:
 
     :param context: The context identifier of the class, module or method.
     :param log_config: The configuration file for the logger.
-    :param identity: The id of the group the messages from this logger will belong, used by fluentd default
-    configuration to group logs by pod.
-    :param workspace_path: The workspace path where the log will be stored at (only apply to fluentd)
+    configuration to group logs by deployment.
     :return:: an executor object.
     """
 
-    supported = {'FileHandler', 'StreamHandler', 'SysLogHandler', 'FluentHandler'}
+    supported = {'FileHandler', 'StreamHandler', 'SysLogHandler', 'RichHandler'}
 
     def __init__(
         self,
         context: str,
         name: Optional[str] = None,
         log_config: Optional[str] = None,
-        identity: Optional[str] = None,
-        workspace_path: Optional[str] = None,
         quiet: bool = False,
         **kwargs,
     ):
+        from jina import __resources_path__, __uptime__, __windows__
 
         if not log_config:
             log_config = os.getenv(
@@ -64,11 +63,8 @@ class JinaLogger:
         if quiet or os.getenv('JINA_LOG_CONFIG', None) == 'QUIET':
             log_config = os.path.join(__resources_path__, 'logging.quiet.yml')
 
-        if not identity:
-            identity = os.getenv('JINA_LOG_ID', None)
-
         if not name:
-            name = os.getenv('JINA_POD_NAME', context)
+            name = os.getenv('JINA_DEPLOYMENT_NAME', context)
 
         # Remove all handlers associated with the root logger object.
         for handler in logging.root.handlers[:]:
@@ -81,11 +77,7 @@ class JinaLogger:
             'name': name,
             'uptime': __uptime__,
             'context': context,
-            'workspace_path': workspace_path
-            or os.getenv('JINA_LOG_WORKSPACE', '/tmp/jina/'),
         }
-        if identity:
-            context_vars['log_id'] = identity
 
         self.add_handlers(log_config, **context_vars)
         self.success = lambda *x: self.logger.log(LogVerbosity.SUCCESS, *x)
@@ -126,6 +118,8 @@ class JinaLogger:
         :param config_path: Path of config file.
         :param kwargs: Extra parameters.
         """
+        from jina import __windows__
+
         self.logger.handlers = []
 
         with open(config_path) as fp:
@@ -144,6 +138,13 @@ class JinaLogger:
             if h == 'StreamHandler':
                 handler = logging.StreamHandler(sys.stdout)
                 handler.setFormatter(fmt(cfg['format'].format_map(kwargs)))
+            if h == 'RichHandler':
+                kwargs_handler = copy.deepcopy(cfg)
+                kwargs_handler.pop('format')
+
+                handler = RichHandler(**kwargs_handler)
+                handler.setFormatter(fmt(cfg['format'].format_map(kwargs)))
+
             elif h == 'SysLogHandler' and not __windows__:
                 if cfg['host'] and cfg['port']:
                     handler = SysLogHandlerWrapper(address=(cfg['host'], cfg['port']))
@@ -169,23 +170,6 @@ class JinaLogger:
                     filename = filename.replace(':', '.')
                 handler = logging.FileHandler(filename, delay=True)
                 handler.setFormatter(fmt(cfg['format'].format_map(kwargs)))
-            elif h == 'FluentHandler':
-                from ..importer import ImportExtensions
-
-                with ImportExtensions(required=False, verbose=False):
-                    from fluent import asynchandler as fluentasynchandler
-                    from fluent.handler import FluentRecordFormatter
-
-                    handler = fluentasynchandler.FluentHandler(
-                        cfg['tag'],
-                        host=cfg['host'],
-                        port=cfg['port'],
-                        queue_circular=True,
-                    )
-
-                    cfg['format'].update(kwargs)
-                    fmt = FluentRecordFormatter(cfg['format'])
-                    handler.setFormatter(fmt)
 
             if handler:
                 self.logger.addHandler(handler)
