@@ -1,21 +1,29 @@
-from jina import __version__
+import os
+
+from jina import __default_executor__, __version__
+from jina.enums import PodRoleType
 from jina.hubble.helper import parse_hub_uri
 from jina.hubble.hubio import HubIO
-from jina.enums import PodRoleType
-from jina import __default_executor__
 
 
 def get_image_name(uses: str) -> str:
     """The image can be provided in different formats by the user.
     This function converts it to an image name which can be understood by k8s.
     It uses the Hub api to get the image name and the latest tag on Docker Hub.
+
+    If you don't want to rebuild image on Jina Hub,
+    you can set `JINA_HUB_NO_IMAGE_REBUILD` environment variable.
+
     :param uses: image name
 
     :return: normalized image name
     """
     try:
+        rebuild_image = 'JINA_HUB_NO_IMAGE_REBUILD' not in os.environ
         scheme, name, tag, secret = parse_hub_uri(uses)
-        meta_data, _ = HubIO.fetch_meta(name, tag, secret=secret, force=True)
+        meta_data, _ = HubIO.fetch_meta(
+            name, tag, secret=secret, rebuild_image=rebuild_image, force=True
+        )
         image_name = meta_data.image_name
         return image_name
     except Exception:
@@ -63,6 +71,7 @@ def construct_runtime_container_args(cargs, uses_metas, uses_with, pod_type):
     :return: Arguments to pass to container
     """
     import json
+
     from jina.helper import ArgNamespace
     from jina.parsers import set_pod_parser
 
@@ -75,6 +84,7 @@ def construct_runtime_container_args(cargs, uses_metas, uses_with, pod_type):
         'workspace_id',
         'upload_files',
         'noblock_on_start',
+        'env',
     }
 
     if pod_type == PodRoleType.HEAD:
