@@ -1,5 +1,4 @@
 """Decorators and wrappers designed for wrapping :class:`BaseExecutor` functions. """
-import contextlib
 import functools
 import inspect
 from functools import wraps
@@ -18,8 +17,6 @@ from jina.helper import convert_tuple_to_list, iscoroutinefunction
 from jina.serve.executors.metas import get_default_metas
 
 if TYPE_CHECKING:
-    from prometheus_client import Summary
-
     from jina import DocumentArray
 
 
@@ -118,12 +115,7 @@ def requests(
                 async def arg_wrapper(
                     executor_instance, *args, **kwargs
                 ):  # we need to get the summary from the executor, so we need to access the self
-                    with self._get_summary(
-                        executor_instance._summary_method,
-                        executor_instance.__class__.__name__,
-                        fn.__name__,
-                    ):
-                        return await fn(executor_instance, *args, **kwargs)
+                    return await fn(executor_instance, *args, **kwargs)
 
                 self.fn = arg_wrapper
             else:
@@ -132,12 +124,7 @@ def requests(
                 def arg_wrapper(
                     executor_instance, *args, **kwargs
                 ):  # we need to get the summary from the executor, so we need to access the self
-                    with self._get_summary(
-                        executor_instance._summary_method,
-                        executor_instance.__class__.__name__,
-                        fn.__name__,
-                    ):
-                        return fn(executor_instance, *args, **kwargs)
+                    return fn(executor_instance, *args, **kwargs)
 
                 self.fn = arg_wrapper
 
@@ -154,15 +141,6 @@ def requests(
 
             setattr(owner, name, self.fn)
 
-        def _get_summary(
-            self, summary: Optional['Summary'], executor_name: str, method_name: str
-        ) -> ContextManager:
-            return (
-                summary.labels(method_name, executor_name).time()
-                if summary
-                else contextlib.nullcontext()
-            )
-
     if func:
         return FunctionMapper(func)
     else:
